@@ -20,22 +20,22 @@ return array(
 	 */
 	'ui_theme'		=> 'smoothness',
 	/**
-	 * Bootswatch̃e[}I
+	 * Bootswatchのテーマを選択
 	 * http://bootswatch.com/
 	 * ameria, cerulean, cosmo, cyborg, flatly, journal, lumen, readable, 
 	 * simplex, slate, spacelab, superhero, united, yeti
 	 */ 
 	'bootswatch' => 'readable',
 	/**
-	 * NavibarnvOCłACR\
+	 * Navibar系プラグインでもアイコンを表示する
 	 */
 	'showicon'		=> true,
 	/**
-	 * AhX̑ɃpX\
+	 * アドレスの代わりにパスを表示
 	 */
 	'topicpath'		=> true,
 	/**
-	 * Sݒ
+	 * ロゴ設定
 	 */
 	'logo'=>array(
 		'src'		=> IMAGE_URI.'pukiwiki_adv.logo.png',
@@ -44,13 +44,13 @@ return array(
 		'height'	=> '80'
 	),
 	/**
-	 * L\̈
+	 * 広告表示領域
 	 */
 	'adarea'	=> array(
-		// y[W̉E̍L\̈
+		// ページの右上の広告表示領域
 		'header'	=> <<<EOD
 EOD
-,		// y[W̍L\̈
+,		// ページ下部の広告表示領域
 		'footer'	=> <<<EOD
 EOD
 	)
