@@ -21,22 +21,6 @@ $skin_file = isset($_COOKIE['skin_file']) ? $_COOKIE['skin_file'] : SKIN_FILE_DE
 // 雛形とするページの読み込みを可能にする(1:する 0:しない)
 $load_template_func = 0;
 
-/////////////////////////////////////////////////
-// 元ページのリンクを自動的に先頭につける(1:つける 0:つけない)
-$load_refer_related = 0;
-
-/////////////////////////////////////////////////
-// 検索文字列を色分けする(1:する 0:しない)
-$search_word_color = 1;
-
-/////////////////////////////////////////////////
-// 添付ファイルの一覧を常に表示する (負担がかかります)
-$attach_link = 1;
-
-/////////////////////////////////////////////////
-// 関連するページのリンク一覧を常に表示する(負担がかかります)
-$related_link = 1;
-
 /////////////////////////////////////////////////
 // WikiName,BracketNameに経過時間を付加する
 $show_passage = 0;
