@@ -8,7 +8,7 @@
  * @copyright 2012-2015 PukiWiki Advance Developers Team
  * @create    2012/12/18
  * @license   GPL v2 or (at your option) any later version
- * @version   $Id: Render.php,v 1.0.1 2015/02/27 21:32:00 Logue Exp $
+ * @version   $Id: Render.php,v 1.0.3 2015/07/24 19:21:00 Logue Exp $
  */
 
 namespace PukiWiki;
@@ -42,7 +42,7 @@ class Render{
 	/**
 	 * jQueryのバージョン
 	 */
-	const JQUERY_VER = '2.1.3';
+	const JQUERY_VER = '2.2.3';
 	//const JQUERY_VER = '1.11.2';
 	/**
 	 * jQuery UIのバージョン
@@ -55,11 +55,11 @@ class Render{
 	/**
 	 * Twitter Bootstrapのバージョン
 	 */
-	const TWITTER_BOOTSTRAP_VER = '3.3.4';
+	const TWITTER_BOOTSTRAP_VER = '3.3.6';
 	/**
 	 * Font Awesomeのバージョン
 	 */
-	const FONT_AWESOME_VER = '4.3.0';
+	const FONT_AWESOME_VER = '4.6.3';
 	/**
 	 * スキンスクリプト（未圧縮）
 	 */
@@ -219,7 +219,7 @@ class Render{
 			// 注釈
 			global $foot_explain;
 			ksort($foot_explain, SORT_NUMERIC);
-			$notes = ! empty($foot_explain) ? '<ul>'.join("\n", $foot_explain).'</ul>' : '';
+			$notes = count($foot_explain) !== 0 ? '<ul>'.join("\n", $foot_explain).'</ul>' : '';
 
 			// 検索語句をハイライト
 			if (isset($vars['word'])){
@@ -230,15 +230,21 @@ class Render{
 			$view->notes = $notes;
 
 			// モードによって、3カラム、2カラムを切り替える。
-			$view->menubar = Factory::Wiki($menubar)->has() ? PluginRenderer::executePluginBlock('menu') : null;
-			if ( Factory::Wiki($sidebar)->has()){
-				// サイドバーが定義されている場合３カラム
-				$view->sidebar = Factory::Wiki($sidebar)->has() ? PluginRenderer::executePluginBlock('side') : null;
-				$view->colums = View::CLASS_THREE_COLUMS;
-			}else{
+			$isExistSideBar = Factory::Wiki($sidebar)->has();
+
+			// #nomenubarが指定されると$menubarはnullになる
+			if(empty($menubar) && !$isExistSideBar) {
+				$view->colums = View::CLASS_NO_COLUMS;
+			}elseif(empty($menubar) || !$isExistSideBar){
 				$view->colums = View::CLASS_TWO_COLUMS;
+			}else{
+				$view->colums = View::CLASS_THREE_COLUMS;
 			}
 
+			$view->menubar = !empty($menubar) && Factory::Wiki($menubar)->has() ? PluginRenderer::executePluginBlock('menu') : null;
+
+			$view->sidebar = $isExistSideBar ? PluginRenderer::executePluginBlock('side') : null;
+
 			// ステータスアイコン
 			if ($this->wiki->isFreezed()){
 				// 錠前マーク（フリーズされてる）
@@ -419,7 +425,7 @@ class Render{
 			if ($this->cmd === 'read'){
 				global $keywords, $description, $site_name, $site_logo;
 				// 要約
-				$desc = !empty($description) ? $description : $this->wiki->description();
+				$desc = !empty($description) ? $description : $this->wiki->description(256, $this->body);
 				$meta_tags[] = array('name' => 'description', 'content' => $desc);
 				// キーワード
 				if (!empty($keywords)){ $meta_tags[] =  array('name' => 'keywords', 'content' => $keywords); }
@@ -481,7 +487,7 @@ class Render{
 
 			// Twitter Bootstrap
 			// http://getbootstrap.com/
-			if ($conf['bootswatch'] === false || empty($conf['bootswatch'])){
+			if (isset($conf['bootswatch']) && $conf['bootswatch'] === false || empty($conf['bootswatch'])){
 				$link_tags[] = array('rel'=>'stylesheet', 'href'=>'//' . self::BOOTSTRAP_CDN . '/bootstrap/' . self::TWITTER_BOOTSTRAP_VER . '/css/bootstrap.min.css', 'type'=>'text/css');
 				$link_tags[] = array('rel'=>'stylesheet', 'href'=>'//' . self::BOOTSTRAP_CDN . '/bootstrap/' . self::TWITTER_BOOTSTRAP_VER . '/css/bootstrap-theme.min.css', 'type'=>'text/css', 'id'=>'bootstrap-theme');
 			}else{
@@ -491,7 +497,7 @@ class Render{
 			}
 
 			// jQuery UIのテーマ
-			if (! empty($conf['ui_theme']) && $conf['ui_theme'] !== false){
+			if (isset($conf['ui_theme']) && ! empty($conf['ui_theme']) && $conf['ui_theme'] !== false){
 				$link_tags[] = array('rel'=>'stylesheet', 'href'=>'//code.jquery.com/ui/' . self::JQUERY_UI_VER .'/themes/' . $conf['ui_theme'] . '/jquery-ui.min.css', 'type'=>'text/css', 'id'=>'ui-theme');
 			}
 		}else{
@@ -667,10 +673,9 @@ class Render{
 				'|' . '(' . $pattern . ')' .        // $matches[1]: 検索語句
 				'/sS';
 				// ハイライトさせる関数を生成
-				$decorate_Nth_word = create_function(
-					'$matches',
-					'return isset($matches[1]) ? ' . '\'<mark class="word' .$id .'">\' . $matches[1] . \'</mark>\' : ' . '$matches[0];'
-				);
+				$decorate_Nth_word = function($matches) use($id){
+					return isset($matches[1]) ? '<mark class="word' .$id .'">' . $matches[1] . '</mark>' :  $matches[0];
+                                };
 
 			// 書き換え
 			foreach($contents as $content){
@@ -755,9 +760,8 @@ class Render{
 				$fileinfo = new AttachFile($this->page, $filename);
 				$exists = true;
 				if (!$fileinfo->has()) continue;
-			//	$logfileinfo = new AttachFile($this->page, $filename, 'log');
-			//	var_dump($logfileinfo->filename);
-			//	$count = $logfileinfo->has() ? $logfileinfo->head(0) : '0';
+				$logfileinfo = new AttachFile($this->page, $filename, 'log');
+				$count = $logfileinfo->has() ? $logfileinfo->head(1) : '0';
 				
 				$ret[] = '<dd><a href="' . 
 					Router::get_cmd_uri('attach', null, null, array('pcmd'=>'open','refer'=>$this->page, 'age'=>0, 'openfile'=>$filename)) .
