@@ -31,9 +31,9 @@ abstract class Inline
 	protected $start;   // Origin number of parentheses (0 origin)
 	protected $text;    // Matched string
 
-	protected $type;
+	public $type;
 	protected $page;
-	protected $name;
+	public $name;
 	protected $body;
 	protected $alias;
 
